@@ -1,4 +1,4 @@
-#' Check that all dots in current environment have been used
+#' Check that all dots have been used
 #'
 #' Automatically sets exit handler to run when function terminates, checking
 #' that all elements of `...` have been evaluated.
@@ -24,7 +24,7 @@ check_dots_used <- function(env = parent.frame()) {
       .(check_dots)(environment())
     }, add = TRUE)
   )
-  eval(exit_handler, env)
+  eval_bare(exit_handler, env)
 
   invisible()
 }
@@ -45,3 +45,34 @@ check_dots <- function(env = parent.frame()) {
     immediate. = TRUE
   )
 }
+
+#' Check that all dots are unnamed
+#'
+#' Named arguments in ... are often a sign of misspelled argument names.
+#'
+#' @param env Environment in which to look for ...
+#' @export
+#' @examples
+#' f <- function(..., foofy = 8) {
+#'   check_dots_unnamed()
+#'   c(...)
+#' }
+#'
+#' f(1, 2, 3, foofy = 4)
+#' f(1, 2, 3, foof = 4)
+check_dots_unnamed <- function(env = parent.frame()) {
+  proms <- dots(env, auto_name = FALSE)
+
+  unnamed <- is.na(names(proms))
+  if (all(unnamed)) {
+    return(invisible())
+  }
+
+  named <- names(proms)[!unnamed]
+  warning(
+    "Some components of ... had unexpected names: ",
+    paste0(named, collapse = ", "),
+    call. = FALSE,
+    immediate. = TRUE
+  )
+}
